@@ -327,6 +327,39 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get_latest_fund_style_box {e} from {StyleBox.__tablename__}')
                 return
 
+    def get_funds_latest_fund_style_box(self, fund_list:Tuple[str]):
+        # x： 0 价值型 40 平衡型 60 成长型 100
+        # y： 0 小盘 25 中盘 50 大盘 100
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                sub_q = mn_session.query(
+                    StyleBox.fund_id.label('temp_id'),
+                    func.max(StyleBox.datetime).label('temp_date'),
+                ).filter(
+                    StyleBox.fund_id.in_(fund_list),
+                ).group_by(StyleBox.fund_id).subquery()
+
+                query = mn_session.query(
+                    StyleBox.fund_id,
+                    StyleBox.x,
+                    StyleBox.y,
+                    StyleBox.datetime,
+                ).filter(
+                    StyleBox.fund_id == sub_q.c.temp_id,
+                    StyleBox.datetime == sub_q.c.temp_date
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                df['x'] = df['x'].map(lambda x: 0 if x < 0 else x)
+                df['x'] = df['x'].map(lambda x: 300 if x > 300 else x)
+                df['y'] = df['y'].map(lambda y: 0 if y < 0 else y)
+                df['y'] = df['y'].map(lambda y: 400 if y > 400 else y)
+                df['x'] = df['x'] / 3
+                df['y'] = df['y'] / 4
+                return df
+            except Exception as e:
+                print(f'Failed to get_latest_fund_style_box {e} from {StyleBox.__tablename__}')
+                return
+
     def get_fund_style_box(self, fund_id: Tuple[str] = (), datetime: str = ''):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
@@ -555,3 +588,32 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to delete data <err_msg> {e} from {FOFNav.__tablename__}')
                 return False
+
+    def get_fof_position(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FOFPosition,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFPosition.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_position <err_msg> {e} from {FOFPosition.__tablename__}')
+
+    def delete_fof_position(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFPosition
+                ).filter(
+                    FOFPosition.fof_id.in_(fof_id_list),
+                    FOFPosition.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFPosition.__tablename__}')
+                return False
