@@ -30,6 +30,7 @@ from .third_party_portfolio.danjuan import DanjuanPortfolioProcessor
 from .third_party_portfolio.em import EmPortfolioProcessor
 from .third_party_portfolio.gf_sec import GFSecPortfolioProcessor
 from .third_party_portfolio.manually_crawled import ManuallyCrawledPortfolioProcessor
+from .fund_manager_processor_advanced import ManagerProcessorDev
 from ...api.basic import BasicDataApi
 
 
@@ -69,6 +70,7 @@ class DerivedDataProcessor:
         self._em_portfolio_processor = EmPortfolioProcessor(self._data_helper)
         self._gf_sec_portfolio_processor = GFSecPortfolioProcessor(self._data_helper)
         self._manually_crawled_portfolio_processor = ManuallyCrawledPortfolioProcessor(self._data_helper)
+        self._manager_processor_dev = ManagerProcessorDev(self._data_helper)
 
     def process_all(self, start_date, end_date):
         failed_tasks = []
@@ -124,6 +126,8 @@ class DerivedDataProcessor:
                     print(f'monthly indicator only update on the last day of month, not today {end_date_dt}')
                 else:
                     failed_tasks.extend(self.fund_indicator_processor_monthly.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._manager_processor_dev.process(end_date))
+
         except Exception as e:
             print(e)
             traceback.print_exc()
