@@ -49,10 +49,25 @@ class OverseaFundNavAnalysis:
             fund_list = self.fund_info[(self.fund_info['fund_type'] == fund_type) & (self.fund_info.benchmark_final.isnull())].index.tolist()
             self.fund_info.loc[fund_list,'benchmark_final'] = benchmark
         self.fund_nav = self._raw_api.get_oversea_fund_nav(end_date=end_date)
-        self.index_price = self._raw_api.get_oversea_index_price(end_date=end_date)
         self.fund_nav = self.fund_nav.pivot_table(index='datetime',columns='codes',values='nav').replace(0,np.nan).ffill()
+        self.fund_nav_adj = self._raw_api.get_oversea_fund_nav_adj(end_date=end_date)
+        self.fund_nav_adj = self.fund_nav_adj.pivot_table(index='datetime',columns='codes',values='nav').replace(0,np.nan).ffill()
+        self.index_price = self._raw_api.get_oversea_index_price(end_date=end_date)        
         self.index_price = self.index_price.pivot_table(index='datetime',columns='codes',values='close').replace(0,np.nan).ffill()
 
+    def get_update_date(self, df_new, df_old, dt_col='datetime'): # dt_col in other db maybe report_date
+        codes_list = df_new.codes.unique().tolist()
+        res = []
+        for code_i in codes_list:
+            exsited_dt = df_old[df_old.codes == code_i]
+            exsited_dt = pd.to_datetime(exsited_dt.datetime.values[-1]).date()
+            _df = df_new[(df_new.codes == code_i)&(df_new.datetime > exsited_dt)]
+            idx = codes_list.index(code_i)
+            if idx % 50 == 0:
+                print(idx)
+            res.append(_df)
+        return pd.concat(res)
+
     def rolling_cur_mdd(self, x):
         if pd.isnull(x).all():
             return np.nan
@@ -82,7 +97,7 @@ class OverseaFundNavAnalysis:
         return _df
 
     def process_current_mdd(self):
-        _df = self.fund_nav.rolling(window=self.fund_nav.shape[0],min_periods=2).apply(self.rolling_cur_mdd, raw=True)
+        _df = (self.fund_nav / self.fund_nav.cummax()) - 1
         _df = pd.DataFrame(_df.stack())
         _df.columns=['current_mdd']
         _df = _df.reset_index()
@@ -110,21 +125,25 @@ class OverseaFundNavAnalysis:
             if fund_id in ['HKATAF01','HKJFCNG'] or fund_id not in self.fund_nav:
                 continue
             fund_nav_i = self.fund_nav[[fund_id]]
+            fund_nav_adj_i = self.fund_nav_adj[[fund_id]]
             benchmark_id = self.fund_info.loc[fund_id].benchmark_final
             if not benchmark_id in self.index_price or benchmark_id in ['USC0TR03','G0O1','I02885JP']:
                 benchmark_id = self.DEFAULT_BENCHMARK[self.fund_info.loc[fund_id,'fund_type']]
             fund_nav_i = fund_nav_i.join(self.index_price[benchmark_id]).ffill().dropna()
             fund_nav_i.columns = ['fund','benchmark']
+            fund_nav_adj_i = fund_nav_adj_i.join(self.index_price[benchmark_id]).ffill().dropna()
+            fund_nav_adj_i.columns = ['fund','benchmark']
             last_day = fund_nav_i.index.values[-1]
             # 不同年度
             for year in [1,3,5]:
                 b_d = last_day - datetime.timedelta(days=365*year)
                 _fund_nav_i = fund_nav_i.loc[b_d:]
+                _fund_nav_adj_i = fund_nav_adj_i.loc[b_d:]
                 if _fund_nav_i.fund.pct_change().std() < 0.0005:
                     continue
                 res_i_m = CalculatorBase.get_stat_result(
-                        dates = _fund_nav_i.index.values,
-                        values = _fund_nav_i.fund.values,
+                        dates = _fund_nav_adj_i.index.values,
+                        values = _fund_nav_adj_i.fund.values,
                         risk_free_rate=0.015,
                         frequency='1M',
                         ret_method='pct_ret',
@@ -157,7 +176,6 @@ class OverseaFundNavAnalysis:
 
     def process_radar_score(self):
         indicator_df = self._raw_api.get_qs_fund_indicator()
-        indicator_df = indicator_df[indicator_df.data_cycle == 1].drop(columns=['data_cycle']).set_index('codes')
         dt = indicator_df.datetime.unique().tolist()[0]
         dic = {
                 'annual_ret':'ret_ability',
@@ -166,25 +184,15 @@ class OverseaFundNavAnalysis:
                 'down_capture':'bear_ability',
                 'alpha':'alpha_ability',
                 'mdd':'drawdown_ability',}
-        indicator_df = self._raw_api.get_qs_fund_indicator()
         indicator_df = indicator_df[indicator_df.data_cycle == 3].drop(columns=['data_cycle']).set_index('codes')
         _df = indicator_df.copy()
         _df = _df[list(dic.keys())].rename(columns=dic)
         _df['risk_ability'] = - _df['risk_ability']
         _df['bear_ability'] = - _df['bear_ability']
         _df['drawdown_ability'] = - _df['drawdown_ability']
-        _df = ((_df.rank(pct=True) * 4 + 1)).round(0).astype(int)
+        _df = _df.rank(pct=True)
         _df['total_score'] = _df.mean(axis=1).rank(pct=True)
-        _res = _df['total_score'].tolist()
-        res = []
-        for i in _res:
-            i = i * 5 + 0.5
-            if i == 5.5:
-                i = 5
-            else:
-                i = int(round(i,0))
-            res.append(i)
-        _df['total_score'] = res
+        _df = (_df / 0.2).apply(np.ceil)
         _df = _df.reset_index()
         _df.loc[:,'datetime'] = dt
         type_dic = {}
@@ -192,7 +200,7 @@ class OverseaFundNavAnalysis:
             fund_list = self.fund_info[self.fund_info.fund_type.isin(fund_types)].index.tolist()
             for i in fund_list:
                 type_dic[i] = fund_types[0]
-        _df.loc[:,'type'] = _df.codes.map(lambda x:type_dic[x])
+        _df.loc[:,'fund_type'] = _df.codes.map(lambda x:type_dic[x])
         type_dic = {
             'ret_ability':int,
             'risk_ability':int,
