@@ -177,9 +177,9 @@ class WebRawDataDownloader(object):
             start_timestamp = str(int((start_date).timestamp()))
             end_timestamp = str(int((datetime.datetime.strptime(end_date, '%Y%m%d') + datetime.timedelta(days=1)).timestamp()))
             url_postfix = f'?period1={start_timestamp}&period2={end_timestamp}&interval=1d&events=history'
-            url_type_list = ['%5EGSPC', '%5EN225', '%5EGDAXI']
-            csv_list = ['^GSPC.csv', '^N225.csv', '^GDAXI.csv']
-            index_list = ['sp500', 'n225', 'dax30']
+            url_type_list = ['%5EGSPC', '%5EN225', '%5EGDAXI', '%5EFTSE', '%5EDJI', '%5Eixic']
+            csv_list = ['^GSPC.csv', '^N225.csv', '^GDAXI.csv', '^FTSE.csv', '^DJI.csv', '^IXIC.csv']
+            index_list = ['sp500', 'n225', 'dax30', 'ftse100', 'dji', 'ixic']
             df_list = []
             for url_type, csv_i, index_i in zip(url_type_list, csv_list, index_list):
                 url = url_prefix + url_type + url_postfix
