@@ -52,7 +52,7 @@ class FundDataManager(DataManager):
 
     def __init__(self, start_time=None, end_time=None, fund_score_param: FundScoreParam = None, score_manager: FundScoreManager = None, s3_retriever_activation: Optional[List[str]] = None):
         DataManager.__init__(self,
-            start_time or datetime.datetime(2005, 1, 1),
+            start_time or datetime.datetime(2011, 1, 1),
             end_time or datetime.datetime.now()
         )
         self._s3_retriever = S3RetrieverForDM(activation=s3_retriever_activation)
@@ -487,7 +487,6 @@ class FundDataManager(DataManager):
             self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _df,how='left',left_on=['fund_id','datetime'],right_on=['fund_id','datetime'])
             _index_list = ['hs300','csi500','gem']
 
-            self.dts.fund_indicator['active'] = self.dts.fund_indicator.fund_id.transform(lambda x: 0 if x in _normal_funds_index_dic and _normal_funds_index_dic[x] in _index_list else 1)
             self.dts.fund_indicator['index_id'] = self.dts.fund_indicator.fund_id.apply(lambda x: self.dts.fund_index_map.get(x, None))
             _fund_indicator_whole = self.dts.fund_indicator.copy()
             self.dts.fund_indicator = self.dts.fund_indicator.dropna(subset=['index_id'])
@@ -502,8 +501,11 @@ class FundDataManager(DataManager):
             self.dts.fund_indicator['fund_size'] = self.dts.fund_indicator['fund_size'].fillna(0)
             _single_fac_df = combine_factor()
             #_single_fac_df = combine_factor_test()
-            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _single_fac_df, how='left', on=['datetime','fund_id'])
-            
+            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _single_fac_df, how='outer', on=['datetime','fund_id'])
+            self.dts.fund_indicator['active'] = self.dts.fund_indicator.fund_id.transform(lambda x: 0 if x in _normal_funds_index_dic and _normal_funds_index_dic[x] in _index_list else 1)
+            self.dts.fund_indicator['index_id'] = self.dts.fund_indicator.fund_id.apply(lambda x: self.dts.fund_index_map.get(x, None))
+            self.dts.fund_indicator = self.dts.fund_indicator.drop_duplicates(subset=['fund_id','datetime'])
+
             _tm_deriv_apply_manager_rank = time.time()
 
             if use_weekly_monthly_indicators:
