@@ -4,7 +4,8 @@ from typing import Optional, List
 import re
 import datetime
 import os
-import math
+import traceback
+import time
 
 import pandas as pd
 
@@ -31,6 +32,7 @@ class HedgeFundNAVReader:
         '虚拟后净值': 'v_net_value',
         '虚拟净值': 'v_net_value',
         '计提后单位净值': 'v_net_value',
+        '虚拟计提净值': 'v_net_value',
         '复权累计净值': 'adjusted_net_value',
         '复权净值': 'adjusted_net_value',
         '净值(分红再投)': 'adjusted_net_value',
@@ -86,6 +88,8 @@ class HedgeFundNAVReader:
         df = pd.read_excel(file_path)
         df = df.loc[:, ['产品名称', '产品代码', '日期', '单位净值', '累计单位净值']]
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df = df.replace({'S3ZS26': 'SJE335'})
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
         return df
 
     @staticmethod
@@ -107,6 +111,7 @@ class HedgeFundNAVReader:
         df = pd.read_excel(file_path)
         df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟后净值']]
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
         return df
 
     @staticmethod
@@ -115,11 +120,27 @@ class HedgeFundNAVReader:
         dates_data = df.index.name.split('：')
         assert (len(dates_data) >= 2) and (dates_data[0] == '日期'), 'invalid format from TaiChuangXiShuoCTA'
         df = df.loc[['单位净值', '累计单位净值'], :].T
-        df['datetime'] = pd.to_datetime(dates_data[1], infer_datetime_format=True).date()
+        df['datetime'] = pd.to_datetime(str(dates_data[1]), infer_datetime_format=True).date()
         df['fund_id'] = 'SNH765'
         df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
         return df
 
+    @staticmethod
+    def _read_for_TaiChuangXiShuoCTANormalWithPrism(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟后净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
+        return df
+
+    @staticmethod
+    def _read_for_TaiChuangXiShuoCTANormal(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟计提净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
+        return df
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -139,7 +160,7 @@ class HedgeFundNAVReader:
             data = mar.get_excels(IMAP_SPType.IMAP_QQ, self._user_name, self._password, uid_last)
         except Exception as e:
             self._notify_error_event(f'FATAL ERROR!! get new data of hedge fund nav failed (e){e}')
-            return False
+            return
 
         uid_last_succeed: Optional[bytes] = None
         df_list: List[pd.DataFrame] = []
@@ -168,6 +189,11 @@ class HedgeFundNAVReader:
                     df = HedgeFundNAVReader._read_for_XinPu10(file_path)
                 elif 'SNH765泰创-羲朔CTA' in name:
                     df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTA(file_path)
+                elif '泰创-羲朔CTA' in name:
+                    if '棱镜' in name:
+                        df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTANormalWithPrism(file_path)
+                    else:
+                        df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTANormal(file_path)
                 else:
                     raise NotImplementedError('unknown hedge fund nav file from attachment')
             except Exception as e:
@@ -184,7 +210,9 @@ class HedgeFundNAVReader:
                     print(f'[read_navs_and_dump_to_db] duplicated data, do not process it (name){name}')
                 # 走到这里都认为是已经处理完了这条数据
                 uid_last_succeed = uid
+                time.sleep(1)
             except Exception as e:
+                traceback.print_exc()
                 self._notify_error_event(f'{e} (dump) (name){name} (file_path){file_path}')
                 continue
 
@@ -194,45 +222,45 @@ class HedgeFundNAVReader:
                 print(whole_df)
             except Exception as e:
                 self._notify_error_event(f'{e} (concat)')
-                return False
+                return
             else:
                 self._wechat_bot.send_hedge_fund_nav_update(whole_df)
                 print(f'[read_navs_and_dump_to_db] done (uid_last){uid_last_succeed} (df){whole_df}')
         else:
+            whole_df = None
             print(f'[read_navs_and_dump_to_db] no new data this time, done (uid_last){uid_last_succeed}')
         # 记录下成功的最后一个uid
         if uid_last_succeed is not None:
             with open(os.path.join(self._read_dir, UID_FILE_NAME), 'wb') as f:
                 f.write(uid_last_succeed)
-                return True
-        return False
+            return whole_df
+        return
 
     def _dump_to_db(self, df: pd.DataFrame):
         def _check_after_merged(x: pd.Series, now_df: pd.DataFrame):
             try:
-                now_data = now_df.loc[(x.fund_id, x.datetime)]
-                if math.isclose(now_data.net_asset_value, x.net_asset_value) and \
-                   math.isclose(now_data.acc_unit_value, x.acc_unit_value) and \
-                   math.isclose(now_data.v_net_value, x.v_net_value):
+                now_data = now_df[(now_df.fund_id == x.fund_id) & (now_df.datetime == x.datetime)]
+                if now_data[['net_asset_value', 'acc_unit_value', 'v_net_value']].iloc[0].astype('float64').equals(x[['net_asset_value', 'acc_unit_value', 'v_net_value']].astype('float64')):
                     return pd.Series(dtype='object')
                 else:
                     return x
-            except KeyError:
+            except (KeyError, IndexError):
                 return x
 
         assert df.datetime.nunique() == 1, 'should have single datetime'
         now_df = BasicDataApi().get_hedge_fund_nav(fund_id_list=list(df.fund_id.unique()))
         if now_df is not None and not now_df.empty:
             # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
-            now_df = now_df.astype({'adjusted_net_value': 'float64', 'v_net_value': 'float64'})
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'change_rate', 'adjusted_net_value']).sort_values(by=['fund_id', 'datetime']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
+            now_df = now_df.astype({'net_asset_value': 'float64', 'acc_unit_value': 'float64', 'v_net_value': 'float64'})
             df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
             df = df.merge(now_df, how='left', on=['fund_id', 'datetime', 'net_asset_value', 'acc_unit_value', 'v_net_value'], indicator=True, validate='one_to_one')
-            df = df[df._merge == 'left_only'].drop(columns=['_merge', 'insert_time_y', 'calc_date_y', 'adjusted_net_value_y']).rename(columns={'insert_time_x': 'insert_time', 'calc_date_x': 'calc_date', 'adjusted_net_value_x': 'adjusted_net_value'})
+            df = df[df._merge == 'left_only'].drop(columns=['_merge', 'insert_time_y', 'calc_date_y']).rename(columns={'insert_time_x': 'insert_time', 'calc_date_x': 'calc_date'})
             if df.empty:
                 return
             # FIXME 没想到特别好的方法 遍历每一行再check一下
-            df = df.apply(_check_after_merged, axis=1, now_df=now_df.set_index(['fund_id', 'datetime']))
+            df['datetime'] = pd.to_datetime(df.datetime, infer_datetime_format=True).dt.date
+            df = df.apply(_check_after_merged, axis=1, now_df=now_df)
             if df.empty:
                 return
             df['insert_time'] = df.insert_time.map(lambda x: x.to_pydatetime())
