@@ -1,5 +1,5 @@
 
-from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum
+from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum, VARCHAR
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, SMALLINT, DATETIME, MEDIUMTEXT
 
@@ -196,9 +196,9 @@ class FundBenchmark(Base):
     assets = Column(CHAR(32))  # 追踪的标的
     industry = Column(CHAR(64))  # 行业分类
 
-    # __table_args__ = (
-    #     Index('idx_em_fund_benchmark_datetime', 'datetime'),
-    # )
+    __table_args__ = (
+        Index('idx_fund_benchmark_fund_id', 'fund_id'),
+    )
 
 
 class TradingDayList(Base):
@@ -793,6 +793,7 @@ class HedgeFundNAV(FOFBase):
     acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False)) # 复权净值
     v_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值的虚拟后净值
+    change_rate = Column(DOUBLE(asdecimal=False))   # 涨跌幅
 
     # 不能加这个 会影响fof backend项目
     # __table_args__ = (
@@ -808,13 +809,40 @@ class HedgeFundInfo(FOFBase):
     fund_id = Column(CHAR(16), primary_key=True)  # 基金ID
     fund_name = Column(TEXT, nullable=False)  # 基金名称
     brief_name = Column(TEXT, nullable=False)  # 基金简称
+    company = Column(VARCHAR(256))                                                   # 公司名称
+    net_asset_value = Column(DOUBLE(asdecimal=False))                                # 单位净值
+    acc_unit_value = Column(DOUBLE(asdecimal=False))                                 # 累计净值
+    adjusted_net_value = Column(DOUBLE(asdecimal=False))                             # 复权净值
+    invest_strategy = Column(VARCHAR(256))                                           # 投资策略
     manager_id = Column(CHAR(16), nullable=False)  # 私募基金公司ID
-    water_line = Column(DOUBLE(asdecimal=False), nullable=False)  # 初始水位线
+    water_line = Column(DOUBLE(asdecimal=False))  # 初始水位线 todo 待删除
     incentive_fee_mode = Column(TEXT)  # 业绩报酬计提方法
     incentive_fee_ratio = Column(DOUBLE(asdecimal=False))  # 业绩计提比例
+    incentive_fee_type = Column(VARCHAR(31))                                          # 业绩提取方式
+    incentive_fee_str = Column(VARCHAR(255))                                          # 业绩提取细则
+    incentive_fee_date = Column(CHAR(20))                                          # 业绩提取日期
     v_nav_decimals = Column(SMALLINT, nullable=False)  # 虚拟净值精度
     size = Column(DOUBLE(asdecimal=False))  # 基金规模
     manager = Column(TEXT)  # 私募基金经理
+    stars = Column(Integer, server_default=text('1'))  # 星级
+    lock_in_period = Column(Integer)                                                    # 封闭期
+    found_date = Column(CHAR(20))                                                       # 成立时间
+    fund_adviser = Column(VARCHAR(31))                                                  # 投资顾问
+    records_no = Column(VARCHAR(127))                                                   # 备案编号
+    records_date = Column(CHAR(20))                                                     # 备案日期
+    deposit_security = Column(VARCHAR(63))                                              # 托管券商
+    open_date = Column(CHAR(20))                                                        # 开放日
+    warning_line = Column(DOUBLE(asdecimal=False))                                      # 预警线
+    closeout_line = Column(DOUBLE(asdecimal=False))                                     # 平仓线
+    management_fee = Column(DOUBLE(asdecimal=False))                                    # 管理费率
+    custodian_fee = Column(DOUBLE(asdecimal=False))                                     # 托管费率
+    administrative_fee = Column(DOUBLE(asdecimal=False))                                # 行政管理费率
+    purchase_fee = Column(DOUBLE(asdecimal=False))                                      # 申购费
+    redeem_fee = Column(DOUBLE(asdecimal=False))                                        # 赎回费
+    purchase_confirmed = Column(Integer)                                                # 申购确认
+    purchase_done = Column(Integer)                                                     # 申购交收
+    redeem_confirmed = Column(Integer)                                                  # 赎回确认
+    redeem_done = Column(Integer)                                                       # 赎回交收
 
 
 # class HedgeFundMgrInfo(Base):
@@ -845,9 +873,16 @@ class FOFInfo(FOFBase):
     lock_up_period = Column(TEXT, nullable=False)  # 锁定期
     incentive_fee_mode = Column(TEXT, nullable=False)  # 业绩报酬计提方法
     incentive_fee = Column(TEXT, nullable=False)  # 业绩报酬提取比例
-    current_deposit_rate = Column(DOUBLE(asdecimal=False), nullable=False)  # 银行活期存款利率
-    initial_raised_fv = Column(DOUBLE(asdecimal=False), nullable=False)  # 初始募集面值
-    initial_net_value = Column(DOUBLE(asdecimal=False), nullable=False)  # 期初总资产净值
+    incentive_fee_type = Column(VARCHAR(31))
+    incentive_fee_str = Column(VARCHAR(255))
+    current_deposit_rate = Column(DOUBLE(asdecimal=False))  # 银行活期存款利率
+    initial_raised_fv = Column(DOUBLE(asdecimal=False))  # 初始募集面值
+    initial_net_value = Column(DOUBLE(asdecimal=False))  # 期初总资产净值
+    total_volume = Column(DOUBLE(asdecimal=False))      # 总资产份额
+    total_amount = Column(DOUBLE(asdecimal=False))      # 资产总额
+    net_asset_value = Column(DOUBLE(asdecimal=False))  # 单位净值
+    acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
+    adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
 
 
 class FOFScaleAlteration(FOFBase):
@@ -872,16 +907,21 @@ class FOFAssetAllocation(FOFBase):
 
     __tablename__ = 'fof_asset_allocation'
 
-    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    datetime = Column(DATE, primary_key=True)  # 日期
-    fund_id = Column(CHAR(16), primary_key=True, nullable=False)  # 申购/赎回基金ID
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    datetime = Column(DATE, primary_key=True)                       # 日期
+    fund_id = Column(CHAR(16), primary_key=True, nullable=False)    # 申购/赎回基金ID
     id = Column(Integer, primary_key=True, autoincrement=True)
-    asset_type = Column(Enum(HoldingAssetType), nullable=False)  # 资产类型
-    amount = Column(DOUBLE(asdecimal=False))  # 申购金额
-    share = Column(DOUBLE(asdecimal=False))  # 赎回份额
-    status = Column(Enum(FundStatus), nullable=False)  # 状态：在途/完成
-    confirmed_date = Column(DATE)  # 确认日期
-    unit_total = Column(DOUBLE(asdecimal=False))  # 确认份额
+    trade_num = Column(VARCHAR(255))                                # 备案编号
+    asset_type = Column(Enum(HoldingAssetType), nullable=False)     # 资产类型
+    amount = Column(DOUBLE(asdecimal=False))                        # 交易金额
+    share = Column(DOUBLE(asdecimal=False))                         # 交易份额
+    nav = Column(DOUBLE(asdecimal=False))                           # 交易净值
+    status = Column(Enum(FundStatus), nullable=False)               # 状态：在途/完成
+    confirmed_date = Column(DATE)                                   # 确认日期
+    event_type = Column(Integer)                                    # 事件类型
+    unit_total = Column(DOUBLE(asdecimal=False))                    # 确认份额
+    water_line = Column(DOUBLE(asdecimal=False))                    # 水位线(累计净值)
+    remark = Column(VARCHAR(255))                                   # 备注
 
 
 class FOFManually(FOFBase):
@@ -917,5 +957,91 @@ class FOFInvestorPosition(FOFBase):
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
     datetime = Column(DATE, primary_key=True)  # 日期
     v_nav = Column(DOUBLE(asdecimal=False))  # 对应到投资人的虚拟净值
+    cost_nav = Column(DOUBLE(asdecimal=False))  # 投资人的平均成本
     amount = Column(DOUBLE(asdecimal=False))  # 总投资额
     shares = Column(DOUBLE(asdecimal=False))  # 总份额
+
+
+class FOFIncidentalStatement(FOFBase):
+    """杂项流水记录"""
+    __tablename__ = 'fof_incidental_statement'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    datetime = Column(DATE)                                         # 日期
+    trade_num = Column(CHAR(128))                                   # 流水编号
+    event_type = Column(Integer)                                    # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                        # 金额
+    remark = Column(VARCHAR(255))                                   # 备注
+
+
+class FOFAccountStatement(FOFBase):
+    """账户流水"""
+    __tablename__ = 'fof_account_statement'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    datetime = Column(DATE)                                         # 日期
+    trade_num = Column(CHAR(128))                                   # 流水编号
+    event_type = Column(Integer)                                    # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                        # 金额
+    remain_cash = Column(DOUBLE(asdecimal=False))                   # 账户余额
+    remark = Column(VARCHAR(255))                                   # 备注
+
+
+class FOFTransitMoney(FOFBase):
+    """在途资金"""
+    __tablename__ = 'fof_transit_money'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                             # 产品ID
+    fund_id = Column(CHAR(20))                                              # 基金ID
+    confirmed_datetime = Column(DATE)                                       # 确认时间
+    event_type = Column(Integer)                                            # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                                # 金额
+    transit_cash = Column(DOUBLE(asdecimal=False))                          # 在途资金总额
+    remark = Column(VARCHAR(255))                                           # 备注
+
+
+class FOFEstimateInterest(FOFBase):
+    """预估利息"""
+    __tablename__ = 'fof_estimate_interest'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                 # 产品ID
+    date = Column(DATE)                                         # 日期
+    remain_cash = Column(DOUBLE(asdecimal=False))               # 当日余额
+    interest = Column(DOUBLE(asdecimal=False))                  # 利息
+    remark = Column(VARCHAR(255))                               # 备注
+    total_interest = Column(DOUBLE(asdecimal=False))            # 总利息
+
+
+class FOFEstimateFee(FOFBase):
+    """预估计提费"""
+    __tablename__ = 'fof_estimate_fee'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    date = Column(DATE)  # 日期
+    pre_market_value = Column(DOUBLE(asdecimal=False))          # 前一日净资产总额
+    management_fee = Column(DOUBLE(asdecimal=False))            # 管理费
+    total_management_fee = Column(DOUBLE(asdecimal=False))      # 累计管理费
+    custodian_fee = Column(DOUBLE(asdecimal=False))             # 托管费
+    total_custodian_fee = Column(DOUBLE(asdecimal=False))       # 累计管理费
+    administrative_fee = Column(DOUBLE(asdecimal=False))        # 行政管理费
+    total_administrative_fee = Column(DOUBLE(asdecimal=False))  # 累计行政管理费
+    is_down = Column(BOOLEAN, default=False)                    # 是否结算
+    remark = Column(VARCHAR(255))                               # 备注
+
+
+class FOFOtherRecord(FOFBase):
+    """其他记录"""
+    __tablename__ = 'fof_other_record'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)                     # 产品ID
+    date = Column(DATE)                                             # 日期
+    event_type = Column(Integer)                                    # 事件类型
+    amount = Column(DOUBLE(asdecimal=False))                        # 金额
+    remark = Column(VARCHAR(255))                                   # 备注
+
