@@ -704,6 +704,26 @@ class FOFNav(FOFBase):
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
     datetime = Column(DATE, primary_key=True)  # 日期
     nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    volume = Column(DOUBLE(asdecimal=False))            # 份额
+    cost = Column(DOUBLE(asdecimal=False))              # 成本
+    mv = Column(DOUBLE(asdecimal=False))                # 市值
+    income = Column(DOUBLE(asdecimal=False))            # 累计收益
+    income_rate = Column(DOUBLE(asdecimal=False))       # 累计收益率
+
+
+class FOFNavPublic(FOFBase):
+    '''fof净值数据发布表'''
+
+    __tablename__ = 'fof_nav_public'
+
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    volume = Column(DOUBLE(asdecimal=False))            # 份额
+    cost = Column(DOUBLE(asdecimal=False))              # 成本
+    mv = Column(DOUBLE(asdecimal=False))                # 市值
+    income = Column(DOUBLE(asdecimal=False))            # 累计收益
+    income_rate = Column(DOUBLE(asdecimal=False))       # 累计收益率
 
 
 class FOFPosition(FOFBase):
@@ -714,3 +734,5 @@ class FOFPosition(FOFBase):
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
     datetime = Column(DATE, primary_key=True)  # 日期
     position = Column(TEXT, nullable=False)  # 持仓信息
+    total_current = Column(DOUBLE(asdecimal=False))            # 流动性资产及负债总计
+
